Demo
====

Here you will find a selection of demos

Content
-------

.. toctree::
   :maxdepth: 1

   oscilator_v1
   oscilator_v2
   oscilator_v3
   lorentz
   tentusscher
   tentusscher_field_parameters
   bidomain
   monodomain
   niederer_benchmark
   multicellmodel
